@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,14 +20,13 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.texttospeech_v1beta1.types import cloud_tts
-
 from .transports.base import TextToSpeechTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import TextToSpeechGrpcAsyncIOTransport
 from .client import TextToSpeechClient
@@ -49,20 +46,16 @@ class TextToSpeechAsyncClient:
     parse_common_billing_account_path = staticmethod(
         TextToSpeechClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(TextToSpeechClient.common_folder_path)
     parse_common_folder_path = staticmethod(TextToSpeechClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(TextToSpeechClient.common_organization_path)
     parse_common_organization_path = staticmethod(
         TextToSpeechClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(TextToSpeechClient.common_project_path)
     parse_common_project_path = staticmethod(
         TextToSpeechClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(TextToSpeechClient.common_location_path)
     parse_common_location_path = staticmethod(
         TextToSpeechClient.parse_common_location_path
@@ -70,7 +63,8 @@ class TextToSpeechAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -85,7 +79,7 @@ class TextToSpeechAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -102,7 +96,7 @@ class TextToSpeechAsyncClient:
 
     @property
     def transport(self) -> TextToSpeechTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             TextToSpeechTransport: The transport used by the client instance.
@@ -116,12 +110,12 @@ class TextToSpeechAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, TextToSpeechTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the text to speech client.
+        """Instantiates the text to speech client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -153,7 +147,6 @@ class TextToSpeechAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = TextToSpeechClient(
             credentials=credentials,
             transport=transport,
@@ -192,7 +185,6 @@ class TextToSpeechAsyncClient:
                 This corresponds to the ``language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -219,7 +211,6 @@ class TextToSpeechAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if language_code is not None:
             request.language_code = language_code
 
@@ -276,7 +267,6 @@ class TextToSpeechAsyncClient:
                 This corresponds to the ``audio_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -303,7 +293,6 @@ class TextToSpeechAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if input is not None:
             request.input = input
         if voice is not None:
